@@ -10,21 +10,6 @@ mtdt <- function(x,n.sim=0)
     a
   }
 
-  tril.old <- function(t)
-  {
-    m <- dim(t)[1]
-    n <- dim(t)[2]
-    if(m!=n) stop("in fact, rows and columns have to be equal")
-    a <- matrix(rep(0,m*n),nrow=m)
-    for(i in 1:m)
-    {
-      for(j in 1:i)
-      {
-        a[i,j] <- t[i,j]
-      }
-    }
-    a
-  }
 #
 # upper triangular matrix 5/6/2004
 #
@@ -35,21 +20,6 @@ mtdt <- function(x,n.sim=0)
     a
   }
 
-  triu.old <- function(t)
-  {
-    m <- dim(t)[1]
-    n <- dim(t)[2]
-    if(m!=n) stop("in fact, rows and columns have to be equal")
-    a <- matrix(rep(0,m*n),nrow=m)
-    for(i in 1:m)
-    {
-      for(j in i:n)
-      {
-        a[i,j] <- t[i,j]
-      }
-    }
-    a
-  }
 #
 # Spielman & Ewens' statistic (diagnoal elements kept)
 # SAS 20/07/1999
